@@ -7,11 +7,11 @@
 # http://search.cpan.org/dist/Devel-NYTProf/
 #
 ###########################################################
-# $Id: Apache.pm 1235 2010-05-26 17:35:13Z tim.bunce $
+# $Id: Apache.pm 998 2009-12-24 14:40:14Z tim.bunce $
 ###########################################################
 package Devel::NYTProf::Apache;
 
-our $VERSION = '3.11';
+our $VERSION = '3.01';
 
 BEGIN {
 
@@ -21,66 +21,44 @@ BEGIN {
 
     if (!$ENV{NYTPROF}) {
         $ENV{NYTPROF} = "file=/tmp/nytprof.$$.out";
-        warn "NYTPROF env var not set, so defaulting to NYTPROF='$ENV{NYTPROF}'";
+        warn "Defaulting NYTPROF env var to '$ENV{NYTPROF}'";
     }
 
-    require Devel::NYTProf::Core;
-
-    DB::set_option("endatexit", 1); # for vhost with PerlOption +Parent
-    DB::set_option("addpid", 1);
-
     require Devel::NYTProf;
 }
 
 use strict;
 
-use constant TRACE => ($ENV{NYTPROF} =~ /\b trace = [^0] /x);
-use constant MP2   => (exists $ENV{MOD_PERL_API_VERSION} && $ENV{MOD_PERL_API_VERSION} == 2);
+use constant MP2 => (exists $ENV{MOD_PERL_API_VERSION} && $ENV{MOD_PERL_API_VERSION} == 2)
+    ? 1
+    : 0;
 
 # https://rt.cpan.org/Ticket/Display.html?id=42862
 die "Threads not supported" if $^O eq 'MSWin32';
 
-# help identify MULTIPLICITY issues
-*current_perl_id = (MP2 and eval "require ModPerl::Util")
-        ? \&ModPerl::Util::current_perl_id
-        : sub { 0+\$$ };
-
-sub trace {
-    return unless TRACE;
-    warn sprintf "NYTProf %d.%s: %s\n",
-        $$, current_perl_id(), shift
-}
-
 sub child_init {
-    trace("child_init(@_)") if TRACE;
     DB::enable_profile() unless $ENV{NYTPROF} =~ m/\b start = (?: no | end ) \b/x;
 }
 
 sub child_exit {
-    trace("child_exit(@_)") if TRACE;
-    DB::finish_profile();
+    DB::_finish();
 }
 
+
 # arrange for the profile to be enabled in each child
 # and cleanly finished when the child exits
 if (MP2) {
-
-    # For mod_perl2 we rely on profiling being active in the parent
-    # and for normal fork detection to detect the new child.
-    # We just need to be sure the profile is finished properly
-    # and an END block works well for that (if loaded right, see docs)
-    # We rely on NYTProf's own END block to finish the profile.
-    #trace("adding child_exit hook") if TRACE;
-    #eval q{ END { child_exit('END') } 1 } or die;
+    require mod_perl2;
+    require Apache2::ServerUtil;
+    my $s = Apache2::ServerUtil->server;
+    $s->push_handlers(PerlChildInitHandler => \&child_init);
+    $s->push_handlers(PerlChildExitHandler => \&child_exit);
 }
 else {
-    # the simple steps for mod_perl2 above might also be fine for mod_perl1
-    # but I'm not in a position to check right now. Try it out and let me know.
     require Apache;
     if (Apache->can('push_handlers')) {
         Apache->push_handlers(PerlChildInitHandler => \&child_init);
         Apache->push_handlers(PerlChildExitHandler => \&child_exit);
-        warn "$$: Apache child handlers installed" if TRACE;
     }
     else {
         Carp::carp("Apache.pm was not loaded");
@@ -101,9 +79,6 @@ Devel::NYTProf::Apache - Profile mod_perl applications with Devel::NYTProf
   PerlPassEnv NYTPROF
   PerlModule Devel::NYTProf::Apache
 
-If you're using virtual hosts with C<PerlOptions> that include either
-C<+Parent> or C<+Clone> then see L</VIRTUAL HOSTS> below.
-
 =head1 DESCRIPTION
 
 This module allows mod_perl applications to be profiled using
@@ -115,11 +90,9 @@ warning and default it to:
 
   file=/tmp/nytprof.$$.out
 
-The file actually created by NTProf will also have the process id appended to
-it because the C<addpid> option is enabled by default.
-
 See L<Devel::NYTProf/"ENVIRONMENT VARIABLES"> for 
 more details on the settings effected by this environment variable.
+
 Try using C<PerlPassEnv> so you can set the NYTPROF environment variable externally.
 
 Each profiled mod_perl process will need to have terminated before you can
@@ -146,28 +119,6 @@ command line.
   </IfDefine>
 
 
-=head1 VIRTUAL HOSTS
-
-If your httpd configuration includes virtual hosts with C<PerlOptions> that
-include either C<+Parent> or C<+Clone> then mod_perl2 will create a new perl
-interpreter to handle requests for that virtual host.
-This causes some issues for profiling.
-
-If C<Devel::NYTProf::Apache> is loaded in the top-level configuration then
-activity in any virtual hosts that use their own perl interpreter won't be
-profiled. Normal virtual hosts will be profiled just fine.
-
-You can profile a I<single> virtual host that uses its own perl interpreter by
-loading C<Devel::NYTProf::Apache> I<inside the configuration for that virtual
-host>. In this case I<do not> use C<PerlModule> directive. You need to use
-a C<Perl> directive instead, like this:
-
-    <VirtualHost *:1234>
-        ...
-        <Perl> use Devel::NYTProf::Apache; </Perl>
-        ...
-    </VirtualHost>
-
 =head1 LIMITATIONS
 
 Profiling mod_perl on Windows is not supported because NYTProf currently
