@@ -7,7 +7,7 @@
 # http://search.cpan.org/dist/Devel-NYTProf/
 #
 ###########################################################
-# $Id: Util.pm 1275 2010-06-07 14:10:32Z tim.bunce@gmail.com $
+# $Id: Util.pm 998 2009-12-24 14:40:14Z tim.bunce $
 ###########################################################
 package Devel::NYTProf::Util;
 
@@ -38,9 +38,9 @@ use base qw'Exporter';
 use Carp;
 use Cwd qw(getcwd);
 use List::Util qw(sum);
-use Devel::NYTProf::Core;
+#use UNIVERSAL qw( isa can VERSION );
 
-our $VERSION = '4.00';
+our $VERSION = '3.01';
 
 our @EXPORT_OK = qw(
     fmt_float
@@ -52,7 +52,6 @@ our @EXPORT_OK = qw(
     get_alternation_regex
     get_abs_paths_alternation_regex
     html_safe_filename
-    trace_level
 );
 
 
